ExNlp.Ranking.ProcessingOptions (ex_nlp v0.1.0)
View SourceShared processing options for ranking algorithms.
These options control how documents and queries are preprocessed before ranking calculations.
Summary
Functions
Gets the tokenizer function, using default if not specified.
Creates processing options from keyword list.